==> vcs-impl-221.5080.210-sources.jar: com/intellij/openapi/vcs/changes/savedPatches/SavedPatchesEditorDiffPreview.kt <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.openapi.vcs.changes.savedPatches

import com.intellij.openapi.Disposable
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.openapi.util.Disposer
import com.intellij.openapi.vcs.changes.ui.ChangesTree
import com.intellij.openapi.vcs.changes.ui.SimpleTreeEditorDiffPreview
import com.intellij.openapi.wm.IdeFocusManager
import com.intellij.util.containers.isEmpty
import java.awt.Component
import javax.swing.JComponent

abstract class SavedPatchesEditorDiffPreview(diffProcessor: SavedPatchesDiffPreview, tree: ChangesTree, targetComponent: JComponent,
                                             private val focusMainComponent: (Component?) -> Unit)
  : SimpleTreeEditorDiffPreview(diffProcessor, tree, targetComponent, false) {
  private var lastFocusOwner: Component? = null

  init {
    Disposer.register(diffProcessor, Disposable { lastFocusOwner = null })
  }

  override fun openPreview(focusEditor: Boolean): Boolean {
    lastFocusOwner = IdeFocusManager.getInstance(project).focusOwner
    return super.openPreview(focusEditor)
  }

  override fun returnFocusToTree() {
    val focusOwner = lastFocusOwner
    lastFocusOwner = null
    focusMainComponent(focusOwner)
  }

  override fun updateAvailability(event: AnActionEvent) {
    event.presentation.isVisible = true
    event.presentation.isEnabled = !changeViewProcessor.allChanges.isEmpty()
  }
}

==> vcs-impl-222.4167.29-sources.jar: com/intellij/openapi/vcs/changes/savedPatches/SavedPatchesEditorDiffPreview.kt <==
// Copyright 2000-2022 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
package com.intellij.openapi.vcs.changes.savedPatches

import com.intellij.openapi.Disposable
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.openapi.util.Disposer
import com.intellij.openapi.vcs.changes.ui.ChangesTree
import com.intellij.openapi.vcs.changes.ui.SimpleTreeEditorDiffPreview
import com.intellij.openapi.wm.IdeFocusManager
import com.intellij.util.containers.isEmpty
import java.awt.Component
import javax.swing.JComponent

abstract class SavedPatchesEditorDiffPreview(diffProcessor: SavedPatchesDiffPreview, tree: ChangesTree, targetComponent: JComponent,
                                             private val focusMainComponent: (Component?) -> Unit)
  : SimpleTreeEditorDiffPreview(diffProcessor, tree, targetComponent, false) {
  private var lastFocusOwner: Component? = null

  init {
    Disposer.register(diffProcessor, Disposable { lastFocusOwner = null })
  }

  override fun openPreview(requestFocus: Boolean): Boolean {
    lastFocusOwner = IdeFocusManager.getInstance(project).focusOwner
    return super.openPreview(requestFocus)
  }

  override fun returnFocusToTree() {
    val focusOwner = lastFocusOwner
    lastFocusOwner = null
    focusMainComponent(focusOwner)
  }

  override fun updateDiffAction(event: AnActionEvent) {
    event.presentation.isVisible = true
    event.presentation.isEnabled = !changeViewProcessor.allChanges.isEmpty()
  }
}
